pub struct Inversion(/* private fields */);Expand description
An inversion is a way to rearrange the notes of a chord so that a different note is the lowest note. Root inversion is stored as 0.
Implementations