#[repr(transparent)]pub struct Interval(pub i16);Expand description
An interval is the absolute difference in pitch between two notes.
The interval is simply internally the number of half-steps between two notes.
Tuple Fields
0: i16Implementations
Sourceimpl Interval
impl Interval
pub const UNISON: Self
pub const MINOR_SECOND: Self
pub const MAJOR_SECOND: Self
pub const MINOR_THIRD: Self
pub const MAJOR_THIRD: Self
pub const DIMINISHED_FOURTH: Self
pub const PERFECT_FOURTH: Self
pub const TRITONE: Self
pub const PERFECT_FIFTH: Self
pub const AUGMENTED_FIFTH: Self
pub const MINOR_SIXTH: Self
pub const MAJOR_SIXTH: Self
pub const MINOR_SEVENTH: Self
pub const MAJOR_SEVENTH: Self
pub const OCTAVE: Self